%
% ANALYSIS OF TRANSFORM CODING I
%
% This script analyzes the results of transform coding using SPCA
% with infomax and error minimization criteria computed using:
%
%         transform_image_data_criterion_2.m  (infomax)
%         transform_image_data_criterion_3.m  (error minimization)
%         quantize_and_invert_image_transf_crit_2.m
%         quantize_and_invert_image_transf_crit_3.m
%
% See the transform coding part of "image_coding_experiments.m" for
% details.
%
% Moreover, it shows the result of equivalent bit allocation and uniform 
% quantization in the PCA domain (equivalent to SPCA with gamma = 0).
%
% See image_coding_experiments.m for the procedure to encode an image
% before applying this analysis.
% 
% It requires that the user provides the source_folder where the results
% were stored when running the transform coding part of
% "image_coding_experiments.m". In our case:
% 
%  .../exp_metric_ICA_VQ/image_coding_real/data_coding/
%

close all
clear all

source_folder = './exp_metric_ICA_VQ/image_coding_real/data_coding/';

load('barbara256')
pto=[70 75];
A=Im(pto(1):pto(1)+99,pto(2):pto(2)+99);

figure,colormap gray,imagesc(A,[20 220]),axis off,axis square,title('Test Image in the Coding Experiments')
axis([0 101 0 101])
hold on,plot([17.5 17.5],[12.5 30.5],'r-','linewidth',2)
hold on,plot([35.5 35.5],[12.5 30.5],'r-','linewidth',2)
hold on,plot([17.5 35.5],[12.5 12.5],'r-','linewidth',2)
hold on,plot([17.5 35.5],[30.5 30.5],'r-','linewidth',2)


% ORIGINAL IMAGE
load([source_folder,'transformed_4d_image_crit_3'],'A');
im_orig=A;

% RECONSTRUCTED IMAGE FROM THE QUANTIZED SPCA infomax
load([source_folder,'quantized_image_crit_2'],'NN','rq','inv_R','im')
im_2=im;

% RECONSTRUCTED IMAGE FROM THE QUANTIZED SPCA error minimization
load([source_folder,'quantized_image_crit_3'],'NN','rq','inv_R','im')
im_3=im;

% RECONSTRUCTED IMAGE FROM THE QUANTIZED PCA (Euclidean SPCA)

    load('imagenes2x2_pca');

    % Contains the training data for the PCA and the PCA results
    %    dat = zero mean PCA training data
    %    V = PCA transform matrix
    %    m = average in the PCA domain
    %

    % PCA transform of the image

        x = im2col(A,[2 2],'distinct');
        x_pca = V'*x;
        x_pca_center = x_pca - repmat(m,1,length(x_pca(1,:)));

    % Scalar quantization

         M = max(abs(dat)');
         inversab_1_quantiz=scalar_quantization(x_pca_center,M,NN);

    % Inverse     
         dat_barbara_pca = inversab_1_quantiz + repmat(m,1,size(inversab_1_quantiz,2));
         dat_barbara = V*dat_barbara_pca;
         side=sqrt(length(dat_barbara(1,:)));
         im_1=col2im(dat_barbara,[2 2],2*[side side],'distinct');
     
% RECONSTRUCTION ERRORS

error1 = round(100*(mean((A(:)-im_1(:)).^2)))/100;
error2 = round(100*(mean((A(:)-im_2(:)).^2)))/100;
error3 = round(100*(mean((A(:)-im_3(:)).^2)))/100;

% RECONSTRUCTED IMAGES

mi=min(A(:));
ma=max(A(:));

res=sum(NN);

figure,subplot(221),colormap gray,imagesc(A,[mi ma]),axis square,axis off,title({'Original';'resol.: 1024, MSE: 0'})
       subplot(222),colormap gray,imagesc(im_1,[mi ma]),axis square,axis off,title({'PCA';['resol.: ',num2str(res),', MSE: ',num2str(error1)]})
       subplot(223),colormap gray,imagesc(im_2,[mi ma]),axis square,axis off,title({'SPCA infomax';['resol.: ',num2str(res),', MSE: ',num2str(error2)]})       
       subplot(224),colormap gray,imagesc(im_3,[mi ma]),axis square,axis off,title({'SPCA errormin';['resol.: ',num2str(res),', MSE: ',num2str(error3)]})
       
       tile