%
% ANALYSIS OF TRANSFORM CODING II
%
% This script loads the (precomputed) transform coding results for the whole 
% Barbara image using SPCA with gamma=1 (infomax) and gamma=1/3 (error min).
%
% Moreover, this script shows the result of equivalent bit allocation and uniform 
% quantization in the PCA domain (in images PCA is similar to SPCA with gamma = 0,
% plain unfolding).
% 
% See the transform coding part of "image_coding_experiments.m" for
% details on how these data were computed.
% 

clear all
close all

load('barbara256')
pto=[70 75];
im_o=Im(pto(1):pto(1)+99,pto(2):pto(2)+99);

rata=2;  % RATE: 1 (higher compresion ratio), 2, 3, 4  (lower compression ratio)

load(['datos_fig_rate_dist'],'num_1');

resolution = num_1(rata);

%
% BARBARA QUANTIZ. UNIF. PCA 
% (debido a la simetria de los datos y a la rigidez de la transformada, esto es similar al criterio 1)
%

     load('bloques_rate_distortion3','datosb')
     load('datos_e_inicializacion','init_param2','dat')

     factor = linspace(0.05,0.7,10);
     
           N = init_param2.Nbins;       
           NN = round(factor(rata)*N);
           NN = 2*floor(NN/2)+1;
   
           % M = max(abs(datosb)');
           M = max(abs(dat)');
           inversab_1_quantiz=scalar_quantization(datosb,M,NN);

     load('datos_e_inicializacion','m','V')
     dat_barbara_pca = inversab_1_quantiz + repmat(m,1,size(inversab_1_quantiz,2));
     dat_barbara = V*dat_barbara_pca;
     im_1=col2im(dat_barbara,[2 2],[100 100],'distinct');
     figure(2),colormap gray,imagesc(im_1,[20 220]),
     axis square
     axis off
     %print(gcf,'-depsc2',['/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/barb_full_crit_1_rate_',num2str(rata)])
     
%      figure,colormap gray,imagesc(im_1(1:70,1:70),[20 220]),
%      axis square
%      axis off
%      %print(gcf,'-depsc2',['/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/barb_peq_crit_1_rate_',num2str(rata)])


%
% BARBARA CRITERIO 2 (infomax)
%

transfb_2_quantiz=[];
inversab_2_quantiz=[];
for trozo=1:10
    load(['inversa_quantiz_barbara_2_rate_',num2str(rata),'_trozo_',num2str(trozo)],'rq','inv_R');
    transfb_2_quantiz=[transfb_2_quantiz rq];
    inversab_2_quantiz=[inversab_2_quantiz inv_R];
end
load('datos_e_inicializacion','m','V')
dat_barbara_pca = inversab_2_quantiz + repmat(m,1,size(inversab_2_quantiz,2));
dat_barbara = V*dat_barbara_pca;
im_2=col2im(dat_barbara,[2 2],[100 100],'distinct');
     figure(3),colormap gray,imagesc(im_2,[20 220]),
     axis square
     axis off
     %print(gcf,'-depsc2',['/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/barb_full_crit_2_rate_',num2str(rata)])
     
%      figure,colormap gray,imagesc(im_2(1:70,1:70),[20 220]),
%      axis square
%      axis off
%      %print(gcf,'-depsc2',['/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/barb_peq_crit_2_rate_',num2str(rata)])

%
% BARBARA CRITERIO 3 (error min)
%

transfb_3_quantiz=[];
inversab_3_quantiz=[];
for trozo=1:10
    load(['inversa_quantiz_barbara_3_rate_',num2str(rata),'_trozo_',num2str(trozo)],'rq','inv_R');
    transfb_3_quantiz=[transfb_3_quantiz rq];
    inversab_3_quantiz=[inversab_3_quantiz inv_R];
end
load('datos_e_inicializacion','m','V')
dat_barbara_pca = inversab_3_quantiz + repmat(m,1,size(inversab_3_quantiz,2));
dat_barbara = V*dat_barbara_pca;
im_3=col2im(dat_barbara,[2 2],[100 100],'distinct');
     figure(4),colormap gray,imagesc(im_3,[20 220]),
     axis square
     axis off
     %print(gcf,'-depsc2',['/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/barb_full_crit_3_rate_',num2str(rata)])
     
%      figure,colormap gray,imagesc(im_3(1:70,1:70),[20 220]),
%      axis square
%      axis off
%      %print(gcf,'-depsc2',['/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/barb_peq_crit_3_rate_',num2str(rata)])

     figure(1),colormap gray,imagesc(im_o,[20 220]),
     axis square
     axis off
     %print(gcf,'-depsc2',['/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/barb_full_orig'])
     
%      figure,colormap gray,imagesc(im_o(1:70,1:70),[20 220]),
%      axis square
%      axis off
%      %print(gcf,'-depsc2',['/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/barb_peq_orig'])



% error en el dominio original

err1=round(10*mean((im_o(:)-im_1(:)).^2))/10;
err2=round(10*mean((im_o(:)-im_2(:)).^2))/10;
err3=round(10*mean((im_o(:)-im_3(:)).^2))/10;

% error en el dominio PCA

err1_pca = mean(sum((inversab_1_quantiz - datosb).^2));
err2_pca = mean(sum((inversab_2_quantiz - datosb).^2));
err3_pca = mean(sum((inversab_3_quantiz - datosb).^2));

% put error data in the titles

figure(1),title({'Original';'resol.: 1024, MSE: 0'})
figure(2),title({'PCA';['resol.: ',num2str(resolution),', MSE: ',num2str(err1)]})
figure(3),title({'SPCA (infomax)';['resol.: ',num2str(resolution),', MSE: ',num2str(err2)]})
figure(4),title({'SPCA (error min)';['resol.: ',num2str(resolution),', MSE: ',num2str(err3)]})


load(['datos_fig_rate_dist'],'num_1','error1','num_2','error2','num_3','error3');

num_rates=[1:7];
figure(5),plot(num_1(num_rates),sqrt(error1(num_rates)),'rv--','linewidth',2),
hold on,plot(num_2(num_rates),sqrt(error2(num_rates)),'ro-','linewidth',2),
hold on,plot(num_3(num_rates),sqrt(error3(num_rates)),'bo-','linewidth',2),
set(gca,'fontsize',20)
xlabel('Resolution N_i','fontsize',20),ylabel('Distortion (RMSE)','fontsize',20),
legend('\gamma=0 (PCA)','\gamma=1 (infomax)','\gamma=1/3 (error min)','location','southwest')
legend(gca,'boxoff','fontsize',18)
axis([0 275 0 15])

tile