function initialization_4d_texture_data(destination_folder)

%
% INITIALIZATION OF SPCA ON 4d IMAGE TEXTURE DATA
%  
%   This script initializes SPCA for the 4d image texture data 
%   It saves the initialization data in the file "initialization_4d_image_data.mat"
%   in the destination folder provided by the user.
%
%   Both infomax and error minimization criteria are considered.
%
%   Initialization takes about 550 secs for each criteiron (in a Dell
%   PowerEdge2900 processor).
%
%   USE:
%   initialization_4d_texture_data(destination_folder)
%
%    where destination_folder is the place where the result is stored and
%    it is a string like this:
%     destination_folder = ...
%     '/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_reproducible/exp_metric_ICA_VQ/image_coding_real/data_coding/';
%
%

load('imagenes2x2_pca');

m = mean(imagenes2x2pca,2);
dat = imagenes2x2pca - repmat(m,1,size(imagenes2x2pca,2));

%% INICIALIZACION

% Punto origen
pto = [0 0 0 0]';

% Parametros

% Num vecinos
N_datos = length(dat(1,:));         % Number of training samples
% Number of neighbors (percentage of the training samples, e.g 20 %)
Nv = [round(0.2*N_datos)];
% Tau
tau = 20;
% Muelle
muelle = 0.06;
% Num bits
Btotal = 9;
% Distancia fuera manifold
dist_fuera = 1;
% Matriz referencia
Aref = eye(4);

% Metric criterion
CRIT = 3

disp('initializing...')
tic
[init_param3] = initialize_SPCA_2(dat,pto,Nv,tau,muelle,CRIT,Btotal,0,dist_fuera,Aref);
toc
disp('initialized 3!')

save([destination_folder,'initialization_4d_image_data'],'pto','Nv','tau','muelle','Btotal','dist_fuera','Aref','init_param3')


% Metric criterion
CRIT = 2

disp('initializing...')
tic
[init_param2] = initialize_SPCA_2(dat,pto,Nv,tau,muelle,CRIT,Btotal,0,dist_fuera,Aref);
toc
disp('initialized 2!')

save([destination_folder,'initialization_4d_image_data'],'pto','Nv','tau','muelle','Btotal','dist_fuera','Aref','init_param3','init_param2')


% % Metric criterion
% CRIT = 1
% 
% save('/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/datos_e_inicializacion')
% 
% disp('initializing...')
% tic
% [init_param1] = initialize_SPCA_2(dat,pto,Nv,tau,muelle,CRIT,Btotal,0,dist_fuera,Aref);
% toc
% disp('initialized 1!')
% 
% save('/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_experiment2/datos_e_inicializacion')