% function pajaritas2(RV1,RV2,[min1 max1],[min2 max2],Nbins,variable_name,fig,FS)
%
% PAJARITAS2 computes and plots the conditional distribution of some random 
% variable (RV2) given the values of some other random variable (RV1).
% 
% Computations of the conditional PDF are done in the whole range 
% of both variables but the result is shown in the selected visualization 
% range.
%
% 
% x axis = amplitude of RV1 (in the specified visualization range) 
% y axis = amplitude of RV2 
% gray level = p(RV2|RV1) normalized for each value of RV1 
%
% USE: [range1,range2,P_2_1]=pajaritas2(RV1,RV2,[min1 max1],[min2 max2],Nbins,variable_name,fig,fontsize)
%
%  Input:
%        RV1         = Column vector with the samples of random variable 1
%        RV2         = Column vector with the samples of random variable 2
%        [min1 max1] = visualization range for random variable 1
%        [min2 max2] = visualization range for random variable 2
%        Nbins       = Number of bins to compute the conditional histogram
%        variable_name = string with the name of the variable (to set the labels of the axes)
%        fig         = figure number
%
%  Output:
%        Range1      = Range [min max] of random variable 1 (Nbins+1 values in the range)
%        Range2      = Range [min max] of random variable 2 (Nbins values in the range)
%        P_2_1       = Histogram of RV2 conditioned to RV1. Each column of the histogram 
%                      is rescaled to fill the range of intensities.
%                      (for each fixed value of RV1) 

function [Range1,Range2,p_2_1]=pajaritas2(RV1,RV2,range1,range2,Nbins,v_n,fig,FS)
warning off
if (min(RV1)<0)&(max(RV1)>0)
   M1=max([abs(min(RV1)) abs(max(RV1))]);
   m1=-M1;
else
   m1=min(RV1);
   M1=max(RV1); 
end

if (min(RV2)<0)&(max(RV2)>0)
   M2=max([abs(min(RV2)) abs(max(RV2))]);
   m2=-M2;
else
   m2=min(RV2);
   M2=max(RV2); 
end

Range1 = linspace(m1,M1,Nbins+1);
Range2 = linspace(m2,M2,Nbins);

for x=2:length(Range1)            
    p_aux = hist(RV2(find((RV1>=Range1(x-1))&(RV1<Range1(x)))),Range2);
    p_2_1(:,x-1) = p_aux/sum(p_aux);
    p_2_1(:,x-1) = p_aux/max(p_aux);    
end
        
figure(fig),colormap(gray);imagesc(Range1,Range2,1-p_2_1);axis square,
axis([range1(1) range1(2) range2(1) range2(2)]),
set(gca,'fontsize',0.9*FS)
xlabel([v_n,'_i'],'fontsize',FS),
ylabel([v_n,'_j'],'fontsize',FS),
title(['p(',v_n,'_j|',v_n,'_i)'],'fontsize',FS)
