function im = quantize_and_invert_image_transf_crit_2(rate_factor,source_folder,image_transform_file,destination_folder)

%
% Quantize_and_invert_image_transform_crit_2 quantizes the SPCA transform
% (infomax criterion) of an image according to certain rate_factor and inverts 
% the quantized coeffcients back to the spatial domain.
%
% USE:
%  im = quantize_and_invert_image_transform_crit_2(rate_factor,source_folder,image_transform_file,destination_folder)
%
%  where:
%   * rate_factor = factor to be applied to the number of bins per
%                   dimension computed in the initialization: init_param2.Nbins
%                   (see initialize_SPCA_2.m and initialization_4d_texture_data.m)
%
%   * source_folder = string indicating the source folder of the transform data, e.g.
%                   source_folder = '/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_reproducible/exp_metric_ICA_VQ/image_coding_real/data_coding/'
%
%   * image_transform_file = string indicating the file with the image transform data, e.g.
%                   image_transform_file = 'transformed_4d_image_crit_2.mat'
%
%   * destination_folder = string indicating the destination folder where results
%                   will be stored, e.g.
%                   destination_folder = '/media/disk/vista/Papers/aranyas/general_y_analiticas/general/TNN_2012_reproducible/exp_metric_ICA_VQ/image_coding_real/data_coding/'
%                   Note that results will be stored in the file: quantized_image_crit_2.mat
%                   This file contains:
%                        im = reconstructed image
%                        R_T2 = original transform 
%                        NN = number of bins per dimension in the
%                             transformed domain
%                        rq = quantized transform
%                        inv_R = inverse of the quantized transform (in the PCA domain)   
%
%   * im = reconstructed image
%

load('datos_e_inicializacion','dat','init_param2')
load('bloques_rate_distortion_total','transfb_2')
load([source_folder,image_transform_file],'R_T2')
     
     N = init_param2.Nbins;       
     
     transform_2_selec=R_T2; 

     M = max(abs(transfb_2)');
     
     NN = round(rate_factor*N);
     NN = 2*floor(NN/2)+1;
     
     rq=scalar_quantization(transform_2_selec,M,NN);
     
     inv_R=rq;
     for i=1:length(rq(1,:));
         tic
         [inv_R(:,i),Aref] = inv_SPCA_2(dat,rq(:,i),init_param2);
         save([destination_folder,'quantized_image_crit_2'],'rq','inv_R');
         [i toc]
     end

inversab_2_quantiz=inv_R;

load('datos_e_inicializacion','m','V')
dat_barbara_pca = inversab_2_quantiz + repmat(m,1,size(inversab_2_quantiz,2));
dat_barbara = V*dat_barbara_pca;
side=sqrt(length(dat_barbara(1,:)));
im=col2im(dat_barbara,[2 2],2*[side side],'distinct');
     
save([destination_folder,'quantized_image_crit_2'],'NN','rq','inv_R','im');     